using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using InstrumentDrivers;

namespace RSAFQ_Waveform_Example
{
    public partial class dialog : Form
    {
        public dialog()
        {
            InitializeComponent();
        }
        
        private void dialog_Load(object sender, EventArgs e)
        {
            Type.SelectedIndex = 1;
            AmplitudeMode.SelectedIndex = 0;
        }

        private void pathButton_Click(object sender, EventArgs e)
        {
            openFileDialog.Filter = "Waveform files (*.wv)|*.wv|All files (*.*)|*.*";
            openFileDialog.FilterIndex = 1;
            openFileDialog.InitialDirectory = WaveformPath.Text;
            openFileDialog.RestoreDirectory = true;
            openFileDialog.FileName = "";
            if (openFileDialog.ShowDialog() == DialogResult.OK)
                WaveformPath.Text = openFileDialog.FileName;
        }

        private void ExitButton_Click(object sender, EventArgs e)
        {
            if (MessageBox.Show("Are you sure you want to exit?", "Exit?", MessageBoxButtons.YesNo) == DialogResult.Yes)
                Close();
        }

        private void Apply_Click(object sender, EventArgs e)
        {
            rsafq instrument;
            String filename;
            String[] split;

            try
            {
                UseWaitCursor = true;
                System.Windows.Forms.Cursor.Current = Cursors.WaitCursor;
                instrument = new rsafq(ResourceDescriptor.Text, IDQuery.Checked, ResetDevice.Checked);

                split = WaveformPath.Text.Split('\\');
                filename = split[split.Length - 1];

                instrument.MMEMoryDrive("d:\\");
                instrument.MMEMoryChangeDirectory("..");
                instrument.MMEMoryMakeDirectory("example");

                instrument.writeFromFile(WaveformPath.Text, "d:\\example\\example.wv");
                instrument.ARBWaveformSelect("d:\\example\\example.wv");
                instrument.SetARBState(ARBState.Checked);

                instrument.SetActiveOutput(rsafqConstants.OutputAnalog);

                instrument.ConfigureAnalogOutput(OutputState.Checked, 1, Type.SelectedIndex, Decimal.ToDouble(Amplitude.Value), AmplitudeMode.SelectedIndex, 
                                                 Decimal.ToDouble(IOffset.Value) / 1000, Decimal.ToDouble(QOffset.Value) / 1000, BiasState.Checked, Decimal.ToDouble(Bias.Value));

            }
            catch (Exception ex)
            {
                String message;

                message = "Instrument Status Error: ";
                message += ex.Message;
                MessageBox.Show(message);
            }
            System.Windows.Forms.Cursor.Current = Cursors.Arrow;
            UseWaitCursor = false;
        }

        private void Type_SelectedIndexChanged(object sender, EventArgs e)
        {
            Boolean dimmed = false;

            switch (Type.SelectedIndex)
            {
                case rsafqConstants.OutputAnalogTypeUnbalanced:
                    dimmed = false;
                    if (Decimal.ToDouble(Amplitude.Value) < 0 || Decimal.ToDouble(Amplitude.Value) > 0.75) Amplitude.Value = 0.5M;
                    break;
                case rsafqConstants.OutputAnalogTypeBalanced:
                    dimmed = true;
                    if (Decimal.ToDouble(Amplitude.Value) < 0 || Decimal.ToDouble(Amplitude.Value) > 1.5) Amplitude.Value = 1.0M;
                    break;
            }

            BiasState.Enabled = dimmed;
            label10.Enabled = dimmed;

            if (BiasState.Checked == true)
            {
                Bias.Enabled = dimmed;
                label9.Enabled = dimmed;
            }
        }

        private void Amplitude_ValueChanged(object sender, EventArgs e)
        {
            switch (Type.SelectedIndex)
            {
                case rsafqConstants.OutputAnalogTypeUnbalanced:
                    if (Decimal.ToDouble(Amplitude.Value) < 0) Amplitude.Value = 0.0M;
                    if (Decimal.ToDouble(Amplitude.Value) > 0.75) Amplitude.Value = 0.75M;
                    break;
                case rsafqConstants.OutputAnalogTypeBalanced:
                    if (Decimal.ToDouble(Amplitude.Value) < 0) Amplitude.Value = 0.0M;
                    if (Decimal.ToDouble(Amplitude.Value) > 1.5) Amplitude.Value = 1.5M;
                    break;
            }

            //SetCtrlVal(panelHandle, PANEL_OUTPUT_AMPLITUDE, amplitude);
        }

        private void BiasState_CheckedChanged(object sender, EventArgs e)
        {
            Bias.Enabled = BiasState.Checked;
            label9.Enabled = BiasState.Checked;
        }
    }
}